==> pycheops_ultra-1.0.1.tar.gz: pycheops_ultra-1.0.1/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
from setuptools.command.install import install

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

with open(path.join(here, "pycheops/VERSION")) as version_file:
    version = version_file.read().strip()

setup(
    name="pycheops_ultra",
    # VERSION
    version=version,
    description="CHEOPS light curve analysis software",
    long_description=long_description,
    # The project's main homepage.
    url="http://cheops.unibe.ch/",
    # Author details
    author="CHEOPS Science Team",
    author_email="p.maxted@keele.ac.uk",
    # Choose your license
    license="GNU GPLv3",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 1 - Planning",
        # Indicate who your project is intended for
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        # Pick your license as you wish (should match "license" above)
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        "Programming Language :: Python :: 3.6",
    ],
    # What does your project relate to?
    keywords="astronomy",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=["contrib", "docs", "tests"]),
    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],
    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        "numpy>=1.17.2",
        "scipy",
        "astropy>=3.2.2",
        "emcee>=3.0.0",
        "astroquery",
        "numba>=0.44.1",
        "lmfit>=0.9.14",
        "corner",
        "photutils",
        "matplotlib>3.2",
        "celerite2",
        "cdspyreadme",
        "python-dace-client > 2.0.0",
        "tqdm",
    ],
    dependency_links=["https://dace.unige.ch/api/python-dace-client/"],
    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #    'dev': ['check-manifest'],
    #    'test': ['coverage'],
    # },
    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={"pycheops": ["VERSION", "data/*/*", "examples/*/*"]},
    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],
    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        "console_scripts": [
            "calculate_coefficients=pycheops.calculate_coefficients:main",
            "make_xml_files=pycheops.make_xml_files:main",
            "combine=pycheops.combine:main",
        ],
    },
    test_suite="nose.collector",
    tests_require=["nose"],
)

==> pycheops_ultra-1.0.2.tar.gz: pycheops_ultra-1.0.2/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
from setuptools.command.install import install

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open("README.rst", encoding="utf-8") as f:
    long_description = f.read()

with open(path.join(here, "pycheops/VERSION")) as version_file:
    version = version_file.read().strip()

setup(
    name="pycheops_ultra",
    # VERSION
    version=version,
    description="CHEOPS light curve analysis software",
    long_description_content_type="text/x-rst",
    long_description=long_description,
    # The project's main homepage.
    url="http://cheops.unibe.ch/",
    # Author details
    author="CHEOPS Science Team",
    author_email="p.maxted@keele.ac.uk",
    # Choose your license
    license="GNU GPLv3",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 1 - Planning",
        # Indicate who your project is intended for
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        # Pick your license as you wish (should match "license" above)
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        "Programming Language :: Python :: 3.6",
    ],
    # What does your project relate to?
    keywords="astronomy",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=["contrib", "docs", "tests"]),
    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],
    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        "numpy>=1.17.2",
        "scipy",
        "astropy>=3.2.2",
        "emcee>=3.0.0",
        "astroquery",
        "numba>=0.44.1",
        "lmfit>=0.9.14",
        "corner",
        "photutils",
        "matplotlib>3.2",
        "celerite2",
        "cdspyreadme",
        "python-dace-client > 2.0.0",
        "tqdm",
        "ipython==7.30.1",
        "ultranest==3.3.0",
        "cython==0.29.24",
        "pathos==0.2.8",
        "mpi4py>=3.0.0",
        "scikit-learn==0.24.2",
        "statsmodels==0.12.2",
        "cryptography>=36.0.0",
        "h5py>=3.5.0",
        "selenium>=3.141.0",
    ],
    dependency_links=["https://dace.unige.ch/api/python-dace-client/"],
    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #    'dev': ['check-manifest'],
    #    'test': ['coverage'],
    # },
    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={"pycheops": ["VERSION", "data/*/*", "examples/*/*"]},
    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],
    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        "console_scripts": [
            "calculate_coefficients=pycheops.calculate_coefficients:main",
            "make_xml_files=pycheops.make_xml_files:main",
            "combine=pycheops.combine:main",
        ],
    },
    test_suite="nose.collector",
    tests_require=["nose"],
)
